@@ -6,6 +6,7 @@ import confuse
 import requests
 from trakt_scrobbler import config, logger
 from trakt_scrobbler.file_info import get_media_info
+from trakt_scrobbler.notifier import notify
 from trakt_scrobbler.utils import AutoloadError, ResumableTimer
 
 SCROBBLE_VERBS = ('stop', 'pause', 'start')
@@ -23,22 +24,39 @@ class Transition:
     def __init__(self, prev, current):
         self.prev = prev
         self.current = current
-
-    def is_same_media(self) -> bool:
-        return self.current['media_info'] == self.prev['media_info']
+        self._is_same_media = None
 
     def is_state_jump(self, from_: State, to: State) -> bool:
         return self.prev['state'] == from_ and self.current['state'] == to
 
+    @property
+    def from_playing_to_paused(self) -> bool:
+        return (self.prev['state'] == State.Playing and 
+                self.current['state'] == State.Paused)
+
+    @property
+    def is_same_media(self) -> bool:
+        # cache this because it is called multiple times and is relatively expensive
+        if self._is_same_media is None:
+            self._is_same_media = self.current['media_info'] == self.prev['media_info']
+        return self._is_same_media
+
+    @property
     def state_changed(self) -> bool:
         return self.prev['state'] != self.current['state']
 
+    @property
     def elapsed_realtime(self) -> float:
         return self.current['updated_at'] - self.prev['updated_at']
 
+    @property
     def progress(self) -> float:
         return self.current['progress'] - self.prev['progress']
 
+    @property
+    def abs_progress(self) -> float:
+        return abs(self.progress)
+
 
 class Monitor(Thread):
     """Generic base class that polls the player for state changes,
@@ -65,8 +83,11 @@ class Monitor(Thread):
         except AutoloadError as e:
             logger.debug(str(e))
             logger.error(f"Config value autoload failed for {cls.name}.")
+            notify(f"Check log file. {e!s}", category="exception")
         except Exception:
-            logger.exception(f"Config value autoload failed for {cls.name}.")
+            msg = f"Config value autoload failed for {cls.name}."
+            logger.exception(msg)
+            notify(f"{msg} Check log file.", category="exception")
         else:
             return super().__new__(cls)
 
@@ -83,29 +104,30 @@ class Monitor(Thread):
     def autoload_cfg(cls):
         template = getattr(cls, 'CONFIG_TEMPLATE', None)
         monitor_cfg = config['players'][cls.name].get(template)
+        assert monitor_cfg is not None
         auto_keys = {k for k, v in monitor_cfg.items() if v == "auto-detect"}
         if not auto_keys:
             return monitor_cfg
         try:
             loaders = getattr(cls, "read_player_cfg")(auto_keys)
         except AttributeError:
-            logger.debug(f"Auto val not found for {', '.join(auto_keys)}")
-            logger.error(f"Autoload not supported for {cls.name}.")
-            raise AutoloadError
+            raise AutoloadError(param=auto_keys,
+                                extra_msg=f"Autoload not supported for {cls.name}.")
         except FileNotFoundError as e:
-            raise AutoloadError(src=e.filename)
+            raise AutoloadError(src=e.filename, extra_msg="File not found")
+
         while auto_keys:
             param = auto_keys.pop()
             try:
                 param_loader = loaders[param]
             except KeyError:
-                logger.error(f"Autoload not supported for '{param}'.")
-                raise AutoloadError(param)
+                raise AutoloadError(param,
+                                    extra_msg="Autoload not supported for this param")
             try:
                 monitor_cfg[param] = param_loader()
                 logger.debug(f"Autoloaded {cls.name} {param} = {monitor_cfg[param]}")
             except FileNotFoundError as e:
-                raise AutoloadError(src=e.filename)
+                raise AutoloadError(param, src=e.filename, extra_msg="File not found")
         return monitor_cfg
 
     def __init__(self, scrobble_queue):
@@ -176,7 +198,7 @@ class Monitor(Thread):
         if (
             not prev
             or not current
-            or not transition.is_same_media()
+            or not transition.is_same_media
             or prev['state'] == State.Stopped
         ):
             # media changed
@@ -189,14 +211,19 @@ class Monitor(Thread):
             if current:
                 if current['progress'] > self.preview_threshold:
                     yield 'enter_preview'
-                elif not prev or not transition.is_same_media():
+                elif (
+                    not prev 
+                    or not transition.is_same_media
+                    or transition.state_changed
+                    or transition.abs_progress > self.skip_interval
+                ):
                     yield 'scrobble'
-        elif transition.state_changed() or transition.progress() > self.skip_interval:
+        elif transition.state_changed or transition.abs_progress > self.skip_interval:
             # state changed
             if self.preview:
                 if current['state'] == State.Stopped:
                     yield 'exit_preview'
-                elif transition.is_state_jump(State.Playing, State.Paused):
+                elif transition.from_playing_to_paused:
                     yield 'pause_preview'
                 elif current['state'] == State.Playing:
                     yield 'resume_preview'
@@ -205,7 +232,7 @@ class Monitor(Thread):
             elif self.fast_pause:
                 if (
                     current['state'] == State.Stopped
-                    or transition.progress() > self.skip_interval
+                    or transition.abs_progress > self.skip_interval
                 ):
                     yield 'scrobble'
                     yield 'exit_fast_pause'
@@ -216,8 +243,8 @@ class Monitor(Thread):
             else:  # normal state
                 yield 'scrobble'
                 if (
-                    transition.is_state_jump(State.Playing, State.Paused)
-                    and transition.elapsed_realtime() < self.fast_pause_threshold
+                    transition.from_playing_to_paused
+                    and transition.elapsed_realtime < self.fast_pause_threshold
                 ):
                     yield 'enter_fast_pause'
 
