@@ -1,52 +1,40 @@
-from getpass import getpass
-
 import confuse
 from trakt_scrobbler import logger
 from trakt_scrobbler.app_dirs import DATA_DIR
 from trakt_scrobbler.file_info import cleanup_guess
 from trakt_scrobbler.player_monitors.monitor import WebInterfaceMon
-from trakt_scrobbler.utils import read_json, safe_request, write_json
-
-PLEX_TOKEN_PATH = DATA_DIR / "plex_token.json"
-token_data = {}
+from trakt_scrobbler.notifier import notify
 
 
-def plex_token_auth(login, password):
-    auth_params = {
-        "url": "https://plex.tv/users/sign_in.json",
-        "data": {"user[login]": login, "user[password]": password},
-        "headers": {
-            "X-Plex-Client-Identifier": "com.iamkroot.trakt_scrobbler",
-            "X-Plex-Product": "Trakt Scrobbler",
-            "Accept": "application/json",
-        },
-    }
-    return safe_request("post", auth_params)
+class PlexToken:
+    """A simple wrapper for plex token file
+
+    TODO: Use some form of OS-provided encrypted storage
+    """
+    PATH = DATA_DIR / "plex_token.txt"
+
+    @property
+    def data(self):
+        try:
+            return self.PATH.read_text(encoding="utf-8")
+        except FileNotFoundError:
+            pass
+
+    @data.setter
+    def data(self, token_data):
+        self.PATH.write_text(token_data, encoding="utf-8")
+
+    @data.deleter
+    def data(self):
+        self.PATH.unlink(missing_ok=True)
+
+    # TODO: Add a is_valid method?
+
+    def __bool__(self):
+        return bool(self.data)
 
 
-def get_token():
-    global token_data
-    token_data = read_json(PLEX_TOKEN_PATH) or {}
-
-    if not token_data:
-        logger.info("Retrieving plex token")
-        login = input("Plex login ID: ")
-        pwd = getpass()
-        resp = plex_token_auth(login, pwd)
-        if resp.ok:
-            token_data = {"token": resp.json()["user"]["authToken"]}
-            write_json(token_data, PLEX_TOKEN_PATH)
-            logger.info(f"Saved plex token to {PLEX_TOKEN_PATH}")
-        elif resp is not None:
-            print(resp.json().get("error", resp.text))
-            return None
-        else:
-            logger.error(
-                "Unable to get access token. "
-                f"Try deleting {PLEX_TOKEN_PATH!s} and retry."
-            )
-            return None
-    return token_data['token']
+token = PlexToken()
 
 
 class PlexMon(WebInterfaceMon):
@@ -63,13 +51,15 @@ class PlexMon(WebInterfaceMon):
 
     def __init__(self, scrobble_queue):
         try:
-            self.token = get_token()
             self.URL = self.URL.format(**self.config)
         except KeyError:
             logger.exception("Check config for correct Plex params.")
             return
+        self.token = token.data
         if not self.token:
             logger.error("Unable to retrieve plex token.")
+            notify("Unable to retrieve plex token. Rerun plex auth.",
+                   category="exception")
             return
         super().__init__(scrobble_queue)
         self.sess.headers["Accept"] = "application/json"
@@ -87,7 +77,7 @@ class PlexMon(WebInterfaceMon):
             return None
 
         # no user filter
-        if not self.config["scrobble_user"]:
+        if not self.config["scrobble_user"] or "User" not in data["Metadata"][0]:
             return data["Metadata"][0]
 
         for metadata in data["Metadata"]:
@@ -107,20 +97,44 @@ class PlexMon(WebInterfaceMon):
     def get_media_info(self, status_data):
         media_info = self.media_info_cache.get(status_data["ratingKey"])
         if not media_info:
-            media_info = self._get_media_info(status_data)
+            if status_data["type"] == "episode":
+                # get the show's data
+                show_key = status_data["grandparentKey"]
+                show_data = self.media_info_cache.get(show_key)
+                if not show_data:
+                    show_data = self.get_data(self.URL + show_key)
+                    self.media_info_cache[show_key] = show_data
+            else:
+                show_data = None
+            media_info = self._get_media_info(status_data, show_data)
             self.media_info_cache[status_data["ratingKey"]] = media_info
         return media_info
 
     @staticmethod
-    def _get_media_info(status_data):
-        info = {}
+    def _get_media_info(status_data, show_data=None):
         if status_data["type"] == "movie":
-            info = {"type": "movie", "title": status_data["title"]}
+            info = {
+                "type": "movie",
+                "title": status_data["title"],
+                "year": status_data.get("year"),
+            }
         elif status_data["type"] == "episode":
             info = {
                 "type": "episode",
                 "title": status_data["grandparentTitle"],
                 "season": status_data["parentIndex"],
                 "episode": status_data["index"],
+                "year": show_data and show_data.get("year"),
             }
+        else:
+            logger.warning(f"Unknown media type {status_data['type']}")
+            return None
+
+        if info["year"] is not None:
+            info["year"] = year = int(info["year"])
+            # if year is at the end of the title, like "The Boys (2019)", remove it
+            # otherwise it might not show up on Trakt search
+            suffix = f" ({year})"
+            if info["title"].endswith(suffix):
+                info["title"] = info["title"].replace(suffix, "")
         return cleanup_guess(info)
